//version: 1.3
using System;
using System.Data;
using System.Windows.Forms;
using System.Drawing;

namespace TreeView
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class TreeView :IDisposable
	{
		private System.Windows.Forms.TreeView tv;
		public System.Windows.Forms.TreeNode CheckedNode;
		public event EventHandler AfterSelect;
		public event EventHandler AfterCheck;
		private object[] eventObject;
		private object[] eventObject2;
		private ImageList il;
		public string Action;
		public TreeView(Control FormName, int left, int top, int width, int height)
		{
			tv = new System.Windows.Forms.TreeView();
			tv.Left = left;
			tv.Top = top;
			tv.Width = width;
			tv.Height = height;
			FormName.Controls.Add(tv);
			il = new ImageList();
			tv.ImageList = null;
			tv.AfterSelect += new TreeViewEventHandler(tv_AfterSelect);
			tv.AfterCheck += new TreeViewEventHandler(tv_AfterCheck);
			eventObject = new object[] {this,"AfterSelect"};
			eventObject2 = new object[] {this,"AfterCheck"};
		}
		public double DLLVersion
		{
			get {return 1.3;}
		}
		public System.Windows.Forms.TreeView ControlRef
		{
			get {return tv;}
			set {tv = value;}
		}
		public void Focus()
		{
			tv.Focus();
		}
		public void Refresh()
		{
			tv.Refresh();
		}
		public void BringToFront()
		{
			tv.BringToFront();
		}
		public int Indent
		{
			get {return tv.Indent;}
			set {tv.Indent = value;}
		}
		public bool ShowPlusMinus
		{
			get {return tv.ShowPlusMinus;}
			set {tv.ShowPlusMinus = value;}
		}
		public bool ShowLines
		{
			get {return tv.ShowLines;}
			set {tv.ShowLines = value;}
		}
		public bool ShowRootLines
		{
			get {return tv.ShowRootLines;}
			set {tv.ShowRootLines = value;}
		}
		public bool Enabled
		{
			get {return tv.Enabled;}
			set {tv.Enabled = value;}
		}
		public bool Visible
		{
			get {return tv.Visible;}
			set {tv.Visible = value;}
		}
		public int Color
		{
			get {return tv.BackColor.ToArgb();}
			set {tv.BackColor = System.Drawing.Color.FromArgb(value);}
		}
		public int FontColor
		{
			get {return tv.ForeColor.ToArgb();}
			set {tv.ForeColor = System.Drawing.Color.FromArgb(value);}
		}
		public int Height
		{
			get {return tv.Height;}
			set {tv.Height = value;}
		}
		public int Width
		{
			get {return tv.Width;}
			set {tv.Width = value;}
		}
		public int Left
		{
			get {return tv.Left;}
			set {tv.Left = value;}
		}
		public int Top
		{
			get {return tv.Top;}
			set {tv.Top = value;}
		}
		public bool ImageMode
		{
			get {return !(tv.ImageList == null);}
			set
			{
				if (value)
					tv.ImageList = il;
				else
					tv.ImageList = null;
			}
		}
		public void AddImage2 (System.Drawing.Image image)
		{
			il.Images.Add(image);
		}
		public void AddImage1 (string file)
		{
			il.Images.Add(new System.Drawing.Bitmap(file));
		}
		public void ImageSize (int width, int height)
		{
			il.ImageSize = new System.Drawing.Size(width,height);
		}
		public void AddExistingNode (TreeNode treeNode)
		{
			
			tv.Nodes.Add(treeNode);
		}
		public TreeNode AddNewNode (String text)
		{
			TreeNode tn = new TreeNode(text);
			tv.Nodes.Add(tn);
			return tn;
		}
		public TreeNode GetNode (int index)
		{
			return tv.Nodes[index];
		}
		public int Count
		{
			get {return tv.Nodes.Count;}
		}
		public void RemoveAllNodes()
		{
			tv.Nodes.Clear();
		}
		public void RemoveNodeAt(int index)
		{
			tv.Nodes.RemoveAt(index);
		}
		public void RemoveNode (TreeNode node)
		{
			tv.Nodes.Remove(node);
		}
		public void InsertNode (int index,TreeNode node)
		{
			tv.Nodes.Insert(index,node);
		}
		public int IndexOfNode (TreeNode node)
		{
			return tv.Nodes.IndexOf(node);
		}
		public void ExpandAll()
		{
			tv.ExpandAll();
		}
		public bool CheckBoxes
		{
			get {return tv.CheckBoxes;}
			set {tv.CheckBoxes = value;}
		}
		public void CollapseAll()
		{
			tv.CollapseAll();
		}
		public TreeNode SelectedNode
		{
			get {return tv.SelectedNode;}
			set {tv.SelectedNode = value;}
		}
		public string SelectedText
		{
			get {return tv.SelectedNode.Text;}
		}

		private void tv_AfterSelect(object sender, TreeViewEventArgs e)
		{
			if (AfterSelect != null)
			{
				Action = e.Action.ToString().ToLower();
				AfterSelect(eventObject,null);
			}
		}
		private void tv_AfterCheck(object sender, TreeViewEventArgs e)
		{
			if (AfterCheck != null)
			{
				Action = e.Action.ToString().ToLower();
				CheckedNode = e.Node;
				AfterCheck(eventObject2,null);
			}
		}
		public int SelectedImageIndex
		{
			get {return tv.SelectedImageIndex;}
			set {tv.SelectedImageIndex = value;}
		}
		public int ImageIndex
		{
			get {return tv.ImageIndex;}
			set {tv.ImageIndex = value;}
		}
		public void Dispose()
		{
			try
			{
				AfterSelect = null;
				tv.Dispose();
			}
			finally
			{
			}
		}

		
	}
	public class Node
	{

		TreeNode tn;
		public Node()
		{
			

		}
		public TreeNode Value
		{
			get	{return tn;}
			set {tn = value;}
		}
		public void CreateNew (String text)
		{
			tn = new TreeNode(text);
		}
		public TreeNode AddNewNode(String text)
		{
			TreeNode tn2 = new TreeNode(text);
			tn.Nodes.Add(tn2);
			return tn2;
		}
		public string Text
		{
			get {return tn.Text;}
			set {tn.Text = value;}
		}
		public void AddExisitingNode(TreeNode treeNode)
		{
			tn.Nodes.Add(treeNode);
		}
		public TreeNode GetNode(int index)
		{
			return tn.Nodes[index];
		}
		public bool IsRoot
		{
			get {return tn.Parent == null;}
		}
		public TreeNode Parent
		{
			get {return tn.Parent;}
		}
		public int Count
		{
			get {return tn.Nodes.Count;}
		}
		public void RemoveAllNodes()
		{
			tn.Nodes.Clear();
		}
		public void RemoveNodeAt(int index)
		{
			tn.Nodes.RemoveAt(index);
		}
		public void RemoveNode (TreeNode node)
		{
			tn.Nodes.Remove(node);
		}
		public void InsertNode (int index,TreeNode node)
		{
			tn.Nodes.Insert(index,node);
		}
		public int IndexOfNode (TreeNode node)
		{
			return tn.Nodes.IndexOf(node);
		}
		public bool Checked
		{
			get {return tn.Checked;}
			set {tn.Checked = value;}
		}
		public void Expand()
		{
			tn.Expand();
		}
		public void ExpandAll()
		{
			tn.ExpandAll();
		}
		public void Collapse()
		{
			tn.Collapse();
		}
		public int SelectedImageIndex
		{
			get {return tn.SelectedImageIndex;}
			set {tn.SelectedImageIndex = value;}
		}
		public int ImageIndex
		{
			get {return tn.ImageIndex;}
			set {tn.ImageIndex = value;}
		}
	}
}

namespace TrackBar
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class TrackBar:IDisposable
	{
		private System.Windows.Forms.TrackBar tb;
		public event EventHandler ValueChanged;
		private object[] eventObject;
		public TrackBar(Control FormName, int Left, int Top, int Width, int Height, bool IsVertical)
		{
			tb = new System.Windows.Forms.TrackBar();
			tb.Left = Left;
			tb.Top = Top;
			if (IsVertical)
				tb.Orientation = Orientation.Vertical;
			else
				tb.Orientation = Orientation.Horizontal;
			tb.Width = Width;
			tb.Height = Height;
			FormName.Controls.Add(tb);
			eventObject = new object[] {this,"ValueChanged"};
			tb.ValueChanged += new EventHandler(tb_ValueChanged);
		}
		public double DLLVersion
		{
			get {return 1.1;}
		}
		public System.Windows.Forms.TrackBar ControlRef
		{
			get {return tb;}
			set {tb = value;}
		}
		public void Focus()
		{
			tb.Focus();
		}
		public void Refresh()
		{
			tb.Refresh();
		}
		public void BringToFront()
		{
			tb.BringToFront();
		}
		public int Value
		{
			get {return tb.Value;}
			set {tb.Value = value;}
		}
		public int Height
		{
			get {return tb.Height;}
			set {tb.Height = value;}
		}
		public int Width
		{
			get {return tb.Width;}
			set {tb.Width = value;}
		}
		public int Left
		{
			get {return tb.Left;}
			set {tb.Left = value;}
		}
		public int Top
		{
			get {return tb.Top;}
			set {tb.Top = value;}
		}
		public int Maximum
		{
			get {return tb.Maximum;}
			set {tb.Maximum = value;}
		}
		public int Minimum
		{
			get {return tb.Minimum;}
			set {tb.Minimum = value;}
		}
		public bool Enabled
		{
			get {return tb.Enabled;}
			set {tb.Enabled = value;}
		}
		public bool Visible
		{
			get {return tb.Visible;}
			set {tb.Visible = value;}
		}
		public int LargeChange
		{
			get {return tb.LargeChange;}
			set {tb.LargeChange = value;}
		}
		public int SmallChange
		{
			get {return tb.SmallChange;}
			set {tb.SmallChange = value;}
		}
		public int TickFrequency
		{
			get {return tb.TickFrequency;}
			set {tb.TickFrequency = value;}
		}
		public Color BackColor
		{
			get {return tb.BackColor;}
			set {tb.BackColor = value;}
		}

		private void tb_ValueChanged(object sender, EventArgs e)
		{
			if (ValueChanged != null)
			{
				ValueChanged(eventObject,null);
			}

		}
		public void Dispose()
		{
			try
			{
				ValueChanged = null;
				if (tb != null)
					tb.Dispose();
			}
			finally{}
		}

	}
}


namespace ToolBar
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class ToolBar:IDisposable
	{
		private System.Windows.Forms.ToolBar tb;
		private ImageList il = new ImageList();
		public event EventHandler Click;
		private object[] eventObject;
		public int SelectedButton;
		public ToolBar(Form FormName)
		{
			tb = new System.Windows.Forms.ToolBar();
			tb.ImageList = il;
			tb.ButtonClick += new ToolBarButtonClickEventHandler(tb_ButtonClick);
			eventObject = new object[] {this,"Click"};
			FormName.Controls.Add(tb);
		}
	
		public double DLLVersion
		{
			get {return 1.1;}
		}
		public void Refresh()
		{
			tb.Refresh();
		}
		public void AddImage1 (string File)
		{
			il.Images.Add(new System.Drawing.Bitmap(File));
		}
		public void AddImage2 (System.Drawing.Image image)
		{
			il.Images.Add(image);
		}
		public void AddToolBarButton(System.Windows.Forms.ToolBarButton Button)
		{
			tb.Buttons.Add(Button); 
		}

		private void tb_ButtonClick(object sender, ToolBarButtonClickEventArgs e)
		{
			SelectedButton = tb.Buttons.IndexOf(e.Button);
			if (Click != null)
				Click(eventObject,null);
		}
		public void Dispose()
		{
			Click = null;
			if (tb != null)
				tb.Dispose();
		}

	}

	public class ToolBarButton
	{
		private System.Windows.Forms.ToolBarButton tbb;
		public ToolBarButtonStyle stSeparator = ToolBarButtonStyle.Separator;
		public ToolBarButtonStyle stDropDownButton = ToolBarButtonStyle.DropDownButton;
		public ToolBarButtonStyle stPushButton = ToolBarButtonStyle.PushButton;
		public ToolBarButtonStyle stToggleButton = ToolBarButtonStyle.ToggleButton;
		public ToolBarButton()
		{
			tbb = new System.Windows.Forms.ToolBarButton();
		}
		public int ImageIndex
		{
			get {return tbb.ImageIndex;}
			set {tbb.ImageIndex = value;}
		}
		public bool Pushed
		{
			get {return tbb.Pushed;}
			set {tbb.Pushed = value;}
		}
		public ToolBarButtonStyle Style
		{
			set {tbb.Style = value;}
		}
		public bool Enabled
		{
			get {return tbb.Enabled;}
			set {tbb.Enabled = value;}
		}
		public bool Visible
		{
			get {return tbb.Visible;}
			set {tbb.Visible = value;}
		}
		public ContextMenu Menu
		{
			set {tbb.DropDownMenu = value;}
		}
		public System.Windows.Forms.ToolBarButton Value
		{
			get {return tbb;}
			set {tbb = value;}
		}


	}
}

namespace ScrollBar //The namespace name is not important.
{

	//Inherit from IDisposable if you need Basic4ppc to free resources when the application is closed.
	public class ScrollBar:IDisposable 
	{
		private System.Windows.Forms.ScrollBar sb; //The "real" object.
		public event EventHandler ValueChanged; //The event handler name must match the event name.
		private object[] eventObject; //One object[] for each event (one event here).
		
		//At least one public ctor.
		public ScrollBar(Control FormName, int Left, int Top, int Width, int Height, bool IsVertical)
		{
			if (IsVertical)
				sb = new VScrollBar();
			else
				sb = new HScrollBar();
			sb.Left = Left;
			sb.Top = Top;
			sb.Width = Width;
			sb.Height = Height;
			FormName.Controls.Add(sb);
			eventObject = new object[] {this,"ValueChanged"}; //This is the object that will pass with the event.
			//It must be in that format exactly.

			sb.ValueChanged += new EventHandler(sb_ValueChanged);
		}
		public double DLLVersion
		{
			get {return 1.1;}
		}
		public System.Windows.Forms.ScrollBar ControlRef
		{
			get {return sb;}
			set {sb = value;}
		}
		public void Focus()
		{
			sb.Focus();
		}
		public void Refresh()
		{
			sb.Refresh();
		}
		public void BringToFront()
		{
			sb.BringToFront();
		}
		public int Value
		{
			get {return sb.Value;}
			set {sb.Value = value;}
		}
		public int Height
		{
			get {return sb.Height;}
			set {sb.Height = value;}
		}
		public int Width
		{
			get {return sb.Width;}
			set {sb.Width = value;}
		}
		public int Left
		{
			get {return sb.Left;}
			set {sb.Left = value;}
		}
		public int Top
		{
			get {return sb.Top;}
			set {sb.Top = value;}
		}
		public int Maximum
		{
			get {return sb.Maximum;}
			set {sb.Maximum = value;}
		}
		public int Minimum
		{
			get {return sb.Minimum;}
			set {sb.Minimum = value;}
		}
		public bool Enabled
		{
			get {return sb.Enabled;}
			set {sb.Enabled = value;}
		}
		public bool Visible
		{
			get {return sb.Visible;}
			set {sb.Visible = value;}
		}
		public int LargeChange
		{
			get {return sb.LargeChange;}
			set {sb.LargeChange = value;}
		}
		public int SmallChange
		{
			get {return sb.SmallChange;}
			set {sb.SmallChange = value;}
		}

		private void sb_ValueChanged(object sender, EventArgs e)
		{
			if (ValueChanged != null) //You must test this.
			{
				ValueChanged(eventObject,null);
			}
		}
		public void Dispose()
		{
			try
			{
				ValueChanged = null;
				if (sb != null)
					sb.Dispose();
			}
			finally{}
		}

	}
}

namespace ProgressBar
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class ProgressBar:IDisposable
	{
		private System.Windows.Forms.ProgressBar tb;
		public ProgressBar(Control FormName, int Left, int Top, int Width, int Height)
		{
			tb = new System.Windows.Forms.ProgressBar();
			tb.Left = Left;
			tb.Top = Top;
			tb.Width = Width;
			tb.Height = Height;
			FormName.Controls.Add(tb);
		}
		public double DLLVersion
		{
			get {return 1.1;}
		}
		public System.Windows.Forms.ProgressBar ControlRef
		{
			get {return tb;}
			set {tb = value;}
		}
		public void Focus()
		{
			tb.Focus();
		}
		public void Refresh()
		{
			tb.Refresh();
		}
		public void BringToFront()
		{
			tb.BringToFront();
		}
		public int Value
		{
			get {return tb.Value;}
			set {tb.Value = value;}
		}
		public int Height
		{
			get {return tb.Height;}
			set {tb.Height = value;}
		}
		public int Width
		{
			get {return tb.Width;}
			set {tb.Width = value;}
		}
		public int Left
		{
			get {return tb.Left;}
			set {tb.Left = value;}
		}
		public int Top
		{
			get {return tb.Top;}
			set {tb.Top = value;}
		}
		public int Maximum
		{
			get {return tb.Maximum;}
			set {tb.Maximum = value;}
		}
		public int Minimum
		{
			get {return tb.Minimum;}
			set {tb.Minimum = value;}
		}
		public bool Enabled
		{
			get {return tb.Enabled;}
			set {tb.Enabled = value;}
		}
		public bool Visible
		{
			get {return tb.Visible;}
			set {tb.Visible = value;}
		}
		

		public void Dispose()
		{
			try
			{
				if (tb != null)
				{
					tb.Dispose();
				}
			}
			finally{}
		}

	}
}

namespace TabControl
{
	/// <summary>
	/// Summary description for Class1.
	/// </summary>
	public class TabControl:IDisposable
	{
		private Control frm;
		System.Windows.Forms.TabControl tbc;
		Panel pnl = new Panel();
		private object[] eventObject;
		public event EventHandler SelectionChanged;

		private void tbc_SelectedIndexChanged(object sender, EventArgs e)
		{
			if (SelectionChanged != null)
				SelectionChanged(eventObject,null);
		}
		public double DLLVersion
		{
			get {return 1.2;}
		}

		public TabControl (Control formName, int Left, int Top, int Width, int Height)
		{
			frm = formName;
			pnl = new Panel();
			tbc = new System.Windows.Forms.TabControl();
			pnl.Size = tbc.Size = new System.Drawing.Size(Width,Height);
			pnl.Location = new Point(Left,Top);
			tbc.Left = 1;
			tbc.Top = 1;
			eventObject = new object[] {this,"SelectionChanged"};
			tbc.SelectedIndexChanged += new EventHandler(tbc_SelectedIndexChanged);
			pnl.Controls.Add(tbc);
			frm.Controls.Add(pnl);	
			
		}
		public void AddControl (Control controlName, int PageIndex, int Left, int Top)
		{
			controlName.Parent = tbc.TabPages[PageIndex];
			controlName.Location = new Point(Left,Top);
		}
		public void AddTabPage(string Text)
		{
			TabPage tp = new TabPage();
			tp.Text = Text;
			tbc.TabPages.Add(tp);
		}
		public void RemoveTabPage (int PageIndex)
		{
			tbc.TabPages.RemoveAt(PageIndex);
		}
		public int SelectedIndex
		{
			get	{return tbc.SelectedIndex;}
			set {tbc.SelectedIndex = value;}
		}
		public void SetColor (int TabPage,System.Drawing.Color Color)
		{
			tbc.TabPages[TabPage].BackColor = Color;
		}
		public void SetText (int TabPage, string Text)
		{
			tbc.TabPages[TabPage].Text = Text;
		}
		public int PageCount()
		{
			return tbc.TabPages.Count;
		}
		public System.Windows.Forms.TabControl ControlRef
		{
			get {return tbc;}
			set {tbc = value;}
		}
		public void Focus()
		{
			tbc.Focus();
		}
		public void Refresh()
		{
			tbc.Refresh();
		}
		public void BringToFront()
		{
			pnl.BringToFront();
		}
		public int Width
		{
			get {return pnl.Width;}
			set {pnl.Width = value;
				tbc.Width = value;}
		}
		public int Height
		{
			get {return pnl.Height;}
			set {pnl.Height = value; tbc.Height = value;}
		}
		public int Left
		{
			get {return pnl.Left;}
			set {pnl.Left = value;}
		}
		public int Top
		{
			get {return pnl.Top;}
			set {pnl.Top = value;}
		}
		public bool Visible
		{
			get {return pnl.Visible;}
			set {pnl.Visible = value;}
		}
		public bool Enabled
		{
			get {return tbc.Enabled;}
			set {tbc.Enabled = value;}
		}

		public void Dispose()
		{
			try
			{
				SelectionChanged = null;
				tbc.Dispose();
				pnl.Dispose();
			}
			finally{}
		}
	}
}
